@@ -1,5 +1,5 @@
 import AVFoundation
-from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure
+from PyObjCTools.TestSupport import TestCase, min_os_level
 
 
 class TestAVMetadataIdentifiers(TestCase):
@@ -843,7 +843,6 @@ class TestAVMetadataIdentifiers(TestCase):
         )  # noqa: B950
 
     @min_os_level("10.15")
-    @expectedFailure
     def testConstants10_15(self):
         with self.subTest("humanbody"):
             self.assertIsInstance(
@@ -891,3 +890,27 @@ class TestAVMetadataIdentifiers(TestCase):
                 AVFoundation.AVMetadataIdentifierQuickTimeMetadataSpatialOverCaptureQualityScoringVersion,  # noqa: B950
                 str,
             )
+
+    @min_os_level("11.0")
+    def testConstants11_0(self):
+        self.assertIsInstance(
+            AVFoundation.AVMetadataCommonIdentifierAccessibilityDescription, str
+        )
+        self.assertIsInstance(
+            AVFoundation.AVMetadataIdentifierQuickTimeUserDataAccessibilityDescription,
+            str,
+        )
+        self.assertIsInstance(
+            AVFoundation.AVMetadataIdentifierQuickTimeMetadataAccessibilityDescription,
+            str,
+        )
+        self.assertIsInstance(
+            AVFoundation.AVMetadataIdentifierQuickTimeMetadataLocationHorizontalAccuracyInMeters,
+            str,
+        )
+
+    @min_os_level("12.0")
+    def testConstants12_0(self):
+        self.assertIsInstance(
+            AVFoundation.AVMetadataIdentifierQuickTimeMetadataIsMontage, str
+        )
